@@ -1,6 +1,8 @@
 import random
+import socket
 from aishu import setting
 
+
 class date(object):
     def getIp(self):
         ipList = ["192.168.84.105",
@@ -22,7 +24,7 @@ class date(object):
         return random.choice(ipList)
 
     def getAentHostIp(self):
-        ip='10.4.104.197'
+        ip = '10.4.104.197'
         return ip
 
     def getIpVR(self):
@@ -34,4 +36,17 @@ class date(object):
                                                 ip3=random.choice(range(10, 99)), ip4=random.choice(range(10, 99)))
 
     def getTestHostIP(self):
-        return setting.host
\ No newline at end of file
+        return setting.host
+
+    def get_host_ip(self):
+        # 获取计算机名称
+        hostname = socket.gethostname()
+
+        # 获取本机IP
+        host_ip = socket.gethostbyname(hostname)
+        return host_ip
+
+    def get_host_name(self):
+        # 获取计算机名称
+        hostname = socket.gethostname()
+        return hostname
