@@ -33,6 +33,8 @@ def filed(key,inquire=[]):
         'ServiceBusinessID':kai.machine(inquire).ServiceBusiness,
         'pensInfo':kai.machine(inquire).inquirePens,
         'testHostIP':ip.date().getTestHostIP,
+        'service_host_ip': ip.date().get_host_ip,
+        'service_host_name': ip.date().get_host_name,
         'rarserRuleName': objectManager.date().getRuleNameId,
         'dashboardId': objectManager.date().getDashboardId,
         'searchId': objectManager.date().getSearchId,
